==========
Quickstart
==========

A friendly message about how easy it is to use R__NAME__

Getting Started
===============

Start by installing R__NAME__ and making a new directory for your project:

.. code-block:: bash

    $ pip3 install R__NAME__
